# TimeframeCondition

This condition is true if the request is within a certain timeframe 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**condition_type** | **str** | The discriminator for the condition | 
**start_time** | **datetime** | The start time when permission is given. Assumes UTC timezone unless otherwise provided inside the date-time as per RFC 3339.  If omitted, and end_time is provided, it is assumed there is no start_time.  | 
**end_time** | **datetime** | The end time when permission is removed. Assumes UTC timezone unless otherwise provided inside the date-time as per RFC 3339.  If omitted, and start_time is provided, it is assumed there is no end date/time to the condition.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


